@@ -44,11 +44,11 @@ G_BEGIN_DECLS
 #define LIBBRASERO_MEDIA_VERSION_MINOR						\
 	11
 #define LIBBRASERO_MEDIA_VERSION_MICRO						\
-	3
+	4
 #define LIBBRASERO_MEDIA_AGE							\
 	362
 #define LIBBRASERO_MEDIA_INSTALL							\
-	"/usr/local"
+	"/home/mclasen/gnome"
 
 /**
  * To start and stop the library
